@@ -1,5 +1,7 @@
 #!/usr/bin/python
 import numpy as np
+import vine_utils as vu
+import CXParams as CXP
 from CXData import CXData
 from CXData import fft2, ifft2, angle, exp, fftshift, conj, abs
 from CXData import log as nlog
@@ -12,6 +14,7 @@ from CXDb import SimpleDB
 from matplotlib import cm
 from matplotlib.patches import Circle
 from matplotlib.collections import PatchCollection
+import multiprocessing as mp
 import multiprocess
 import itertools
 
@@ -769,8 +772,8 @@ class CXPhasing(CXData):
         self.slow_db_queue['numerical_aperture'] = (NA,)
         self.slow_db_queue['axial_resolution'] = (axial_res,)
 
-        self.slow_db_queue['rms_rounding_error_x'] = (CXP.rms_rounding_error[0],)
-        self.slow_db_queue['rms_rounding_error_y'] = (CXP.rms_rounding_error[1],)
+        #self.slow_db_queue['rms_rounding_error_x'] = (CXP.rms_rounding_error[0],)
+        #self.slow_db_queue['rms_rounding_error_y'] = (CXP.rms_rounding_error[1],)
 
 if __name__ == '__main__':
     CXPh = CXPhasing()
